#!perl

# AUTHOR : Ariel Chai (www.svartberg.com)
# VERSION : 1.2 for modo 3.02 (8.1.2009)
# DESCRIPTION : a smart UV mirror, which mirrors the geometry/UV around the selected verts/edges UV position
# USAGE : select an edge you wish to mirror around and run script. 
#         make sure to work only in one layer, and that you've deleted the other half of the UV.
#

#---------------------------------------------------------------------------#

# Variables
my @layers = lxq("query layerservice layers ? fg");
my $vMap;
my $uvPos;				# the center of mirror
my $mType=0;			# horizontal/vertical mirror (0/1)

&init;
&getPos;
&mirror;
lxout("end");

#---------------------------------------------------------------------------#

sub init {
	#check user is in edge selection
	$selectType = lxq("select.typeFrom typelist:{edge;polygon;vertex;item} ?");
	if ($selectType != 1) {
		die("Select an edge")	
	}

	lx("select.convert vertex");
	
	#get texture vmap
	@vMaps = lxq("query layerservice vmaps ? selected");
	foreach my $v (@vMaps) {
		$vType = lxq("query layerservice vmap.type ? $v");
		if ($vType eq texture) {
			$vMap = $v;
			last;
		}
	}
	
}

sub getPos {
	@verts=lxq("query layerservice selection ? vert");
	$vertsN = @verts - 1;
	my @uvPos;

	# Get position
	my @uvs = lxq("query layerservice uvs ? selected");
	if (@uvs < 2){die("Please select an edge or two verts to align the uv");}
	@uvPos1 = lxq("query layerservice uv.pos ? @uvs[0]");
	$uvT = @uvs[0];
	$uvT =~ tr/\-()//d;
	$uvT =~ s/\d*,//;
	foreach my $uv(@uvs) {
		$uv =~ tr/\-()//d;
		$uv =~ s/\d*,//;
		if ($uv != $uvT) { 
			@uvPos2 = lxq("query layerservice uv.pos ? $uv");
			last;
		}
	}

	if ($uvPos1[1] == $uvPos2[1]) { $mType = 1 }
	lxout("$uvPos1[1] / $uvPos2[1]");
	$uvPos = $uvPos1[$mType];

}

sub mirror {
	lx("select.edgeConnect uv");
	lx("select.convert polygon");

	&uvMirror;
	
	# geometry mirror
	lx("tool.set poly.mirror on");

	if(lxq("query platformservice appversion ?") < 300) { 
		lx("tool.attr poly.mirror axis 0");
		lx("tool.attr poly.mirror cenX 0");
		lx("tool.attr poly.mirror cenY 0");
		lx("tool.attr poly.mirror cenZ 0");
		lx("tool.attr poly.mirror merge 0");
	} else {
		lx("tool.attr gen.mirror axis 0");
		lx("tool.attr gen.mirror cenX 0");
		lx("tool.attr gen.mirror cenY 0");
		lx("tool.attr gen.mirror cenZ 0");
		lx("tool.attr gen.mirror merge 0");
	}
	
	lx("tool.doApply");
	lx("tool.set poly.mirror off 0");
	
	

	&uvMirror;
	
	lx("select.drop polygon");
	lx("vert.merge auto");*/
}

sub uvMirror {
	# uv mirror
	if ($mType == 0) {
		#lx("uv.mirror u $uvPos");
		lx("uv.mirror u $uvPos");
	} else {
		lx("uv.mirror v $uvPos");
	}	
}
